--[[
Edit this file suit your needs 
Place this file in the dzVents scripts folder using the name ideAlarmConfig.lua
See https://github.com/allan-gam/ideAlarm/wiki/configuration
After editing, always verify that it's valid LUA at http://codepad.org/ (Mark your paste as "Private"!!!)
--]]

local _C = {}

local SENSOR_CLASS_A = 'a' -- Sensor can be triggered in both arming modes. E.g. "Armed Home" and "Armed Away".
local SENSOR_CLASS_B = 'b' -- Sensor can be triggered in arming mode "Armed Away" only.

--[[
-------------------------------------------------------------------------------
DO NOT ALTER ANYTHING ABOVE THIS LINE
-------------------------------------------------------------------------------
--]]

_C.ALARM_TEST_MODE = false -- if ALARM_TEST_MODE is set to true it will prevent audible alarm

-- Interval for how often we shall trigger the script to check if nagging about open doors needs to be made 
_C.NAG_SCRIPT_TRIGGER_INTERVAL = {'every other minute'} -- Format as defined by dzVents timers
-- Interval for how often we shall repeat nagging.
_C.NAG_INTERVAL_MINUTES = 6 

-- Number of seconds which after the alert devices will be turned off
-- automatically even if an active alert situation still exists.
-- 0 = Disable automatic turning off alert devices.   
_C.ALARM_ALERT_MAX_SECONDS = 300

--	Uncomment 3 lines below to override the default logging level
_C.loggingLevel = function(domoticz)
	return domoticz.LOG_ERROR-- Select one of LOG_DEBUG, LOG_INFO, LOG_ERROR, LOG_FORCE to override system log level
end

--	If You named your Domoticz Security Panel different from "Security Panel", uncomment the line below to specify the name.
 _C.SECURITY_PANEL_NAME = 'Alarm: Security Panel'

_C.ALARM_ZONES = {
	-- Start configuration of the first alarm zone
	{
		name='Thuis',
		armingModeTextDevID=119,
		statusTextDevID=120,
--		entryDelay=15,
		exitDelay=20,
		alertDevices={},
					 --{'Siren', 'Garden Lights'},
		sensors = {
			-- Voordeur
			['Hal: Voordeur'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 20, ['enabled'] = true},
			
			-- Achterdeur
			['Bijkeuken: Achterdeur'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 0, ['enabled'] = true},
			
			-- Raam bijkeuken
			['Bijkeuken: Raam'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 0, ['enabled'] = true},
			
			-- Schuifpui
			['Woonkamer: Schuifpui'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 0, ['enabled'] = true},
			
			-- Raam slaapkamer
			['Slaapkamer: Raam'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 0, ['enabled'] = function(domoticz) return (domoticz.devices(131).state == 'Off') end},
			
			-- Raam Floris
			['Floris: Raam'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 0, ['enabled'] = function(domoticz) return (domoticz.devices(133).state == 'Off') end},
			
			-- Raam Kantoor
			['Kantoor: Raam'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 0, ['enabled'] = function(domoticz) return (domoticz.devices(132).state == 'Off') end},
			
			-- Raam Badkamer
			['Badkamer: Raam'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 0, ['enabled'] = function(domoticz) return (domoticz.devices(134).state == 'Off') end},
			
			-- Garage deur
			['Garage: Deur'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 0, ['enabled'] = true},

			-- Garage Garagedeur
			['Garage: Garagedeur'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 0, ['enabled'] = true},
			
			-- Berging deur
			['Berging: Deur'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 0, ['enabled'] = true},

			-- Test sensor
--			['Test deursensor'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['entryDelay'] = 20, ['enabled'] = true},
--			['Another Door'] = {['class'] = SENSOR_CLASS_A, ['nag'] = true, ['nagTimeoutMins'] = 5, ['armWarn'] = true, ['enabled'] = true},
		},
		armAwayToggleBtn='Alarm: Arm Away',
		armHomeToggleBtn='Alarm: Arm Home',
		disarmToggleBtn='Alarm: Disarm',
		mainZone = true,
		canArmWithTrippedSensors = true,
		syncWithDomoSec = true, -- Only a single zone is allowed to sync with Domoticz's built in Security Panel
	},
	-- End configuration of the first alarm zone
}

return _C
